@@ -1,21 +1,19 @@
 """ REST views for the Persistent Query Example.
 """
-
+from django.db import IntegrityError
 from rest_framework import status
 from rest_framework.exceptions import ValidationError
+from rest_framework.permissions import IsAdminUser, IsAuthenticated
 from rest_framework.response import Response
 from rest_framework.views import APIView
-from mongoengine import NotUniqueError
 
+from core_main_app.access_control.exceptions import AccessControlError
+from core_main_app.commons import exceptions
 import core_explore_example_app.components.persistent_query_example.api as persistent_query_example_api
-
 from core_explore_example_app.rest.persistent_query_example.serializers import (
     PersistentQueryExampleSerializer,
     PersistentQueryExampleAdminSerializer,
 )
-from core_main_app.commons import exceptions
-from core_main_app.access_control.exceptions import AccessControlError
-from rest_framework.permissions import IsAdminUser, IsAuthenticated
 
 
 class AdminPersistentQueryExampleList(APIView):
@@ -52,8 +50,8 @@ class AdminPersistentQueryExampleList(APIView):
 
             # Return response
             return Response(serializer.data, status=status.HTTP_200_OK)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
@@ -104,8 +102,8 @@ class AdminPersistentQueryExampleList(APIView):
         except ValidationError as validation_exception:
             content = {"message": validation_exception.detail}
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
@@ -144,8 +142,8 @@ class PersistentQueryExampleList(APIView):
 
             # Return response
             return Response(serializer.data, status=status.HTTP_200_OK)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
@@ -237,8 +235,8 @@ class PersistentQueryExampleDetail(APIView):
         except exceptions.DoesNotExist:
             content = {"message": "Object not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
@@ -292,11 +290,11 @@ class PersistentQueryExampleDetail(APIView):
         except ValidationError as validation_exception:
             content = {"message": validation_exception.detail}
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
-        except NotUniqueError as e:
-            content = {"message": str(e)}
+        except IntegrityError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except exceptions.DoesNotExist:
             content = {"message": "Persistent query example not found."}
@@ -333,8 +331,8 @@ class PersistentQueryExampleDetail(APIView):
 
             # Return response
             return Response(status=status.HTTP_204_NO_CONTENT)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except exceptions.DoesNotExist:
             content = {"message": "Persistent query example not found."}
@@ -382,8 +380,8 @@ class PersistentQueryExampleByName(APIView):
         except exceptions.DoesNotExist:
             content = {"message": "Persistent query example not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
