@@ -2,10 +2,16 @@
 """
 from unittest.mock import patch
 
+from django.contrib.auth.models import AnonymousUser
 from django.test import SimpleTestCase
 from rest_framework import status
 
+from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_main_app.utils.tests_tools.RequestMock import RequestMock
 import core_explore_example_app.components.persistent_query_example.api as persistent_query_example_api
+from core_explore_example_app.components.persistent_query_example.models import (
+    PersistentQueryExample,
+)
 from core_explore_example_app.rest.persistent_query_example import (
     views as persistent_query_example_views,
 )
@@ -13,16 +19,14 @@ from core_explore_example_app.rest.persistent_query_example.serializers import (
     PersistentQueryExampleSerializer,
     PersistentQueryExampleAdminSerializer,
 )
-from core_main_app.utils.tests_tools.MockUser import create_mock_user
-from core_main_app.utils.tests_tools.RequestMock import RequestMock
-from core_explore_example_app.components.persistent_query_example.models import (
-    PersistentQueryExample,
-)
-from django.contrib.auth.models import AnonymousUser
 
 
 class TestAdminPersistentQueryExampleListGet(SimpleTestCase):
+    """Test Admin Persistent Query Example List Get"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             persistent_query_example_views.AdminPersistentQueryExampleList.as_view(),
             AnonymousUser(),
@@ -31,6 +35,8 @@ class TestAdminPersistentQueryExampleListGet(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -42,6 +48,8 @@ class TestAdminPersistentQueryExampleListGet(SimpleTestCase):
 
     @patch.object(PersistentQueryExample, "get_all")
     def test_superuser_returns_http_200(self, get_all):
+        """test_superuser_returns_http_200"""
+
         get_all.return_value = {}
         mock_user = create_mock_user("1", is_staff=True, is_superuser=True)
 
@@ -54,7 +62,11 @@ class TestAdminPersistentQueryExampleListGet(SimpleTestCase):
 
 
 class TestPersistentQueryExampleListGet(SimpleTestCase):
+    """Test Persistent Query Example List Get"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_get(
             persistent_query_example_views.PersistentQueryExampleList.as_view(),
             AnonymousUser(),
@@ -62,8 +74,10 @@ class TestPersistentQueryExampleListGet(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
-    @patch.object(PersistentQueryExample, "get_all")
+    @patch.object(PersistentQueryExample, "get_all_by_user")
     def test_authenticated_returns_http_200(self, get_all):
+        """test_authenticated_returns_http_200"""
+
         get_all.return_value = {}
         mock_user = create_mock_user("1")
 
@@ -74,8 +88,10 @@ class TestPersistentQueryExampleListGet(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-    @patch.object(PersistentQueryExample, "get_all")
+    @patch.object(PersistentQueryExample, "get_all_by_user")
     def test_superuser_returns_http_200(self, get_all):
+        """test_superuser_returns_http_200"""
+
         get_all.return_value = {}
         mock_user = create_mock_user("1", is_staff=True, is_superuser=True)
 
@@ -88,7 +104,11 @@ class TestPersistentQueryExampleListGet(SimpleTestCase):
 
 
 class TestPersistentQueryExampleListPost(SimpleTestCase):
+    """Test Persistent Query Example List Post"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_post(
             persistent_query_example_views.AdminPersistentQueryExampleList.as_view(),
             AnonymousUser(),
@@ -105,6 +125,8 @@ class TestPersistentQueryExampleListPost(SimpleTestCase):
         persistent_query_example_serializer_save,
         persistent_query_example_serializer_is_valid,
     ):
+        """test_authenticated_returns_http_201"""
+
         persistent_query_example_serializer_is_valid.return_value = True
         persistent_query_example_serializer_save.return_value = None
         persistent_query_example_serializer_data.return_value = {}
@@ -126,6 +148,8 @@ class TestPersistentQueryExampleListPost(SimpleTestCase):
         persistent_query_example_serializer_save,
         persistent_query_example_serializer_is_valid,
     ):
+        """test_superuser_returns_http_201"""
+
         persistent_query_example_serializer_is_valid.return_value = True
         persistent_query_example_serializer_save.return_value = None
         persistent_query_example_serializer_data.return_value = {}
@@ -141,7 +165,11 @@ class TestPersistentQueryExampleListPost(SimpleTestCase):
 
 
 class TestAdminPersistentQueryExampleListPost(SimpleTestCase):
+    """Test Admin Persistent Query Example List Post"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_post(
             persistent_query_example_views.AdminPersistentQueryExampleList.as_view(),
             AnonymousUser(),
@@ -150,6 +178,8 @@ class TestAdminPersistentQueryExampleListPost(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403"""
+
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_post(
@@ -168,6 +198,8 @@ class TestAdminPersistentQueryExampleListPost(SimpleTestCase):
         persistent_query_example_serializer_save,
         persistent_query_example_serializer_is_valid,
     ):
+        """test_superuser_returns_http_201"""
+
         persistent_query_example_serializer_is_valid.return_value = True
         persistent_query_example_serializer_save.return_value = None
         persistent_query_example_serializer_data.return_value = {}
@@ -183,6 +215,8 @@ class TestAdminPersistentQueryExampleListPost(SimpleTestCase):
 
 
 class TestPersistentQueryExampleDetailGet(SimpleTestCase):
+    """Test Persistent Query Example Detail Get"""
+
     @patch.object(persistent_query_example_api, "get_by_id")
     @patch.object(PersistentQueryExampleSerializer, "data")
     def test_anonymous_returns_http_403(
@@ -190,6 +224,7 @@ class TestPersistentQueryExampleDetailGet(SimpleTestCase):
         mock_persistent_query_example_serializer_data,
         mock_persistent_query_example_api_get_by_id,
     ):
+        """test_anonymous_returns_http_403"""
         mock_persistent_query_example_serializer_data.return_value = {}
         mock_persistent_query_example_api_get_by_id.return_value = None
         response = RequestMock.do_request_get(
@@ -207,6 +242,7 @@ class TestPersistentQueryExampleDetailGet(SimpleTestCase):
         mock_persistent_query_example_serializer_data,
         mock_persistent_query_example_api_get_by_id,
     ):
+        """test_authenticated_returns_http_200"""
         mock_persistent_query_example_serializer_data.return_value = {}
         mock_persistent_query_example_api_get_by_id.return_value = None
         mock_user = create_mock_user("1")
@@ -226,6 +262,7 @@ class TestPersistentQueryExampleDetailGet(SimpleTestCase):
         mock_persistent_query_example_serializer_data,
         mock_persistent_query_example_api_get_by_id,
     ):
+        """test_superuser_returns_http_200"""
         mock_persistent_query_example_serializer_data.return_value = {}
         mock_persistent_query_example_api_get_by_id.return_value = None
         mock_user = create_mock_user("1", is_staff=True)
@@ -240,7 +277,11 @@ class TestPersistentQueryExampleDetailGet(SimpleTestCase):
 
 
 class TestPersistentQueryExampleDetailPatch(SimpleTestCase):
+    """Test Persistent Query Example Detail Patch"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_patch(
             persistent_query_example_views.PersistentQueryExampleDetail.as_view(),
             AnonymousUser(),
@@ -260,6 +301,7 @@ class TestPersistentQueryExampleDetailPatch(SimpleTestCase):
         mock_persistent_query_example_is_valid,
         mock_persistent_query_example_api_get_by_id,
     ):
+        """test_authenticated_returns_http_200"""
         mock_persistent_query_example_data.return_value = {}
         mock_persistent_query_example_save.return_value = None
         mock_persistent_query_example_is_valid.return_value = True
@@ -285,6 +327,7 @@ class TestPersistentQueryExampleDetailPatch(SimpleTestCase):
         mock_persistent_query_example_is_valid,
         mock_persistent_query_example_api_get_by_id,
     ):
+        """test_superuser_returns_http_200"""
         mock_persistent_query_example_data.return_value = {}
         mock_persistent_query_example_save.return_value = None
         mock_persistent_query_example_is_valid.return_value = True
@@ -301,7 +344,11 @@ class TestPersistentQueryExampleDetailPatch(SimpleTestCase):
 
 
 class TestPersistentQueryExampleDetailDelete(SimpleTestCase):
+    """Test Persistent Query Example Detail Delete"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403"""
+
         response = RequestMock.do_request_delete(
             persistent_query_example_views.PersistentQueryExampleDetail.as_view(),
             AnonymousUser(),
@@ -315,6 +362,7 @@ class TestPersistentQueryExampleDetailDelete(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, persistent_query_example_api_delete, persistent_query_example_get_by_id
     ):
+        """test_authenticated_returns_http_200"""
 
         persistent_query_example_api_delete.return_value = None
         persistent_query_example_get_by_id.return_value = None
@@ -333,6 +381,8 @@ class TestPersistentQueryExampleDetailDelete(SimpleTestCase):
     def test_superuser_returns_http_200(
         self, persistent_query_example_api_delete, persistent_query_example_get_by_id
     ):
+        """test_superuser_returns_http_200"""
+
         persistent_query_example_api_delete.return_value = None
         persistent_query_example_get_by_id.return_value = None
         mock_user = create_mock_user("1", is_staff=True)
@@ -347,6 +397,8 @@ class TestPersistentQueryExampleDetailDelete(SimpleTestCase):
 
 
 class TestPersistentQueryExampleByNameGet(SimpleTestCase):
+    """Test Persistent Query Example By Name Get"""
+
     @patch.object(persistent_query_example_api, "get_by_name")
     @patch.object(PersistentQueryExampleSerializer, "data")
     def test_anonymous_returns_http_403(
@@ -354,6 +406,7 @@ class TestPersistentQueryExampleByNameGet(SimpleTestCase):
         mock_persistent_query_example_serializer_data,
         mock_persistent_query_example_api_get_by_name,
     ):
+        """test_anonymous_returns_http_403"""
         mock_persistent_query_example_serializer_data.return_value = {}
         mock_persistent_query_example_api_get_by_name.return_value = None
         response = RequestMock.do_request_get(
@@ -371,6 +424,8 @@ class TestPersistentQueryExampleByNameGet(SimpleTestCase):
         mock_persistent_query_example_serializer_data,
         mock_persistent_query_example_api_get_by_name,
     ):
+        """test_authenticated_returns_http_200"""
+
         mock_persistent_query_example_serializer_data.return_value = {}
         mock_persistent_query_example_api_get_by_name.return_value = None
         mock_user = create_mock_user("1")
@@ -390,6 +445,8 @@ class TestPersistentQueryExampleByNameGet(SimpleTestCase):
         mock_persistent_query_example_serializer_data,
         mock_persistent_query_example_api_get_by_name,
     ):
+        """test_superuser_returns_http_200"""
+
         mock_persistent_query_example_serializer_data.return_value = {}
         mock_persistent_query_example_api_get_by_name.return_value = None
         mock_user = create_mock_user("1", is_staff=True)
